Struct CLI
Source pub struct CLI<'a> {
pub name: Option<&'a str>,
pub version: Option<&'a str>,
pub description: Option<&'a str>,
pub options: Vec<Opt<'a>>,
pub args: Vec<Arg<'a>>,
}
Get the value of a specific option by name
Formats the value using the given formatter.
Read more
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.